==> group_purl-2.0.1.tar.gz: group_purl/src/Context/GroupPurlContext.php <==
<?php

namespace Drupal\group_purl\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Plugin\Context\Context;
use Drupal\Core\Plugin\Context\ContextDefinition;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\group\Entity\Group;
use Drupal\purl\Event\ModifierMatchedEvent;
use Drupal\purl\PurlEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\Entity\EntityTypeManager;

/**
 * Class GroupContext.
 */
class GroupPurlContext implements ContextProviderInterface, EventSubscriberInterface {

  use StringTranslationTrait;
  /**
   * Drupal\Core\Entity\EntityTypeManager definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * @var CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * @var  \Drupal\purl\Event\ModifierMatchedEvent*/
  protected $modifierMatched;

  /**
   * Constructs a new GroupContext object.
   *
   * @param EntityTypeManagerInterface $entity_type_manager
   * @param CurrentRouteMatch $currentRouteMatch
   * @param CurrentPathStack $currentPathStack
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager,
                              CurrentRouteMatch $currentRouteMatch
                              ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->currentRouteMatch = $currentRouteMatch;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[PurlEvents::MODIFIER_MATCHED] = ['onModifierMatched'];

    return $events;
  }

  /**
   * This method is called whenever the purl.modifier_matched event is
   * dispatched.
   *
   * @param \Drupal\purl\Event\ModifierMatchedEvent $event
   */
  public function onModifierMatched(ModifierMatchedEvent $event) {
    //if ($event->getProvider() != 'group_purl_provider') {
      // We are not interested in modifiers not provided by this module.
      //return;
    //}
    $this->modifierMatched = $event;
    $this->contexts[$event->getMethod()->getId()]  = $event->getModifier();
    ksort($this->contexts);
  }

  /**
   * {@inheritdoc}
   */
  public function getRuntimeContexts(array $unqualified_context_ids) {
    // Cache this context on the route.
    $cacheability = new CacheableMetadata();
    $cacheability->setCacheContexts(['purl']);

    $group = $this->getGroupFromRoute();
    if ($group) {
      // Create a context from the definition and retrieved or created group.
      $context = EntityContext::fromEntity($group);
      $context->addCacheableDependency($cacheability);

      return ['group' => $context];
    }
    return [];
  }

  /**
   * For context, in addition to an active Purl context, we also want to include
   * the group view page itself.
   * @return null|\Drupal\group\Entity\Group the active group
   */
  public function getGroupFromRoute() {
    if ($this->modifierMatched !== NULL) {
      $storage = $this->entityTypeManager->getStorage('group');
      $group = $storage->load($this->modifierMatched->getValue());
      return $group;
    }
    return null;
    $routename = $this->currentRouteMatch->getRouteName();
    if (strpos($routename, 'entity.group.') === 0) {
      $group = $this->currentRouteMatch->getParameter('group');
      return $group;
    }

  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableContexts() {
    $context = EntityContext::fromEntityTypeId('group', $this->t('Group from Purl'));
    return ['group' => $context];
  }

}

==> group_purl-2.0.2.tar.gz: group_purl/src/Context/GroupPurlContext.php <==
<?php

namespace Drupal\group_purl\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\purl\Event\ModifierMatchedEvent;
use Drupal\purl\PurlEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class GroupPurlContext.
 */
class GroupPurlContext implements ContextProviderInterface, EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * Drupal\Core\Entity\EntityTypeManager definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The current route match service.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * The modifier matched event.
   *
   * @var \Drupal\purl\Event\ModifierMatchedEvent|null
   */
  protected $modifierMatched;

  /**
   * Contexts collected from events.
   *
   * @var array
   */
  protected $contexts = [];

  /**
   * Constructs a new GroupPurlContext object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Routing\CurrentRouteMatch $currentRouteMatch
   *   The current route match service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, CurrentRouteMatch $currentRouteMatch) {
    $this->entityTypeManager = $entity_type_manager;
    $this->currentRouteMatch = $currentRouteMatch;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[PurlEvents::MODIFIER_MATCHED] = ['onModifierMatched'];
    return $events;
  }

  /**
   * This method is called whenever the purl.modifier_matched event is
   * dispatched.
   *
   * @param \Drupal\purl\Event\ModifierMatchedEvent $event
   *   The event object.
   */
  public function onModifierMatched(ModifierMatchedEvent $event) {
    $this->modifierMatched = $event;
    $this->contexts[$event->getMethod()->getId()] = $event->getModifier();
    ksort($this->contexts);
  }

  /**
   * {@inheritdoc}
   */
  public function getRuntimeContexts(array $unqualified_context_ids) {
    $cacheability = new CacheableMetadata();
    $cacheability->setCacheContexts(['purl']);

    $group = $this->getGroupFromRoute();
    if ($group) {
      $context = EntityContext::fromEntity($group);
      $context->addCacheableDependency($cacheability);
      return ['group' => $context];
    }
    return [];
  }

  /**
   * Retrieves the active group from the route or modifier.
   *
   * @return \Drupal\group\Entity\Group|null
   *   The active group entity, or NULL if none is found.
   */
  public function getGroupFromRoute() {
    if ($this->modifierMatched !== NULL) {
      $storage = $this->entityTypeManager->getStorage('group');
      $group = $storage->load($this->modifierMatched->getValue());
      return $group;
    }

    $routename = $this->currentRouteMatch->getRouteName();
    if ($routename !== null && strpos($routename, 'entity.group.') === 0) {
      $group = $this->currentRouteMatch->getParameter('group');
      return $group;
    }

    return null;
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableContexts() {
    $context = EntityContext::fromEntityTypeId('group', $this->t('Group from Purl'));
    return ['group' => $context];
  }

}
